@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -32,10 +32,7 @@ public:
 
     void archiveFolder(const QString &path, Akonadi::Collection::Id collectionId);
 
-    ArchiveMailKernel *kernel() const
-    {
-        return mArchiveMailKernel;
-    }
+    ArchiveMailKernel *kernel() const;
 
 public Q_SLOTS:
     void load();
