@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,8 +17,8 @@ class FollowUpReminderInfo
 {
 public:
     FollowUpReminderInfo();
-    FollowUpReminderInfo(const KConfigGroup &config);
-    FollowUpReminderInfo(const FollowUpReminderInfo &info);
+    explicit FollowUpReminderInfo(const KConfigGroup &config);
+    explicit FollowUpReminderInfo(const FollowUpReminderInfo &info);
 
     // Can be invalid.
     Q_REQUIRED_RESULT Akonadi::Item::Id originalMessageItemId() const;
