@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,6 +15,7 @@
 #include <QHBoxLayout>
 #include <QHeaderView>
 #include <QIcon>
+#include <QKeyEvent>
 #include <QLocale>
 #include <QMenu>
 #include <QTreeWidget>
@@ -57,7 +58,7 @@ FollowUpReminderInfoWidget::FollowUpReminderInfoWidget(QWidget *parent)
     hbox->setContentsMargins({});
     mTreeWidget->setObjectName(QStringLiteral("treewidget"));
     QStringList headers;
-    headers << i18n("To") << i18n("Subject") << i18n("Dead Line") << i18n("Answer")
+    headers << i18n("To") << i18n("Subject") << i18n("Deadline") << i18n("Answer")
 #ifdef DEBUG_MESSAGE_ID
             << QStringLiteral("Message Id") << QStringLiteral("Answer Message Id")
 #endif
@@ -68,14 +69,31 @@ FollowUpReminderInfoWidget::FollowUpReminderInfoWidget(QWidget *parent)
     mTreeWidget->setRootIsDecorated(false);
     mTreeWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
     mTreeWidget->setContextMenuPolicy(Qt::CustomContextMenu);
+    mTreeWidget->installEventFilter(this);
 
     connect(mTreeWidget, &QTreeWidget::customContextMenuRequested, this, &FollowUpReminderInfoWidget::slotCustomContextMenuRequested);
+    connect(mTreeWidget, &QTreeWidget::itemDoubleClicked, this, &FollowUpReminderInfoWidget::slotItemDoubleClicked);
 
     hbox->addWidget(mTreeWidget);
 }
 
 FollowUpReminderInfoWidget::~FollowUpReminderInfoWidget() = default;
 
+bool FollowUpReminderInfoWidget::eventFilter(QObject *object, QEvent *event)
+{
+    if (object == mTreeWidget) {
+        if (event->type() == QEvent::KeyPress) {
+            auto *keyEvent = static_cast<QKeyEvent *>(event);
+            if (keyEvent->key() == Qt::Key_Delete) {
+                const auto listItems = mTreeWidget->selectedItems();
+                deleteItems(listItems);
+            }
+        }
+    }
+
+    return false;
+}
+
 void FollowUpReminderInfoWidget::setInfo(const QList<FollowUpReminder::FollowUpReminderInfo *> &infoList)
 {
     mTreeWidget->clear();
@@ -169,6 +187,20 @@ bool FollowUpReminderInfoWidget::save() const
     return true;
 }
 
+void FollowUpReminderInfoWidget::slotItemDoubleClicked(QTreeWidgetItem *item)
+{
+    if (!item)
+        return;
+
+    const auto mailItem = static_cast<FollowUpReminderInfoItem *>(item);
+    const auto answerMessageItemId = mailItem->info()->answerMessageItemId();
+    if (answerMessageItemId >= 0) {
+        openShowMessage(answerMessageItemId);
+    } else {
+        openShowMessage(mailItem->info()->originalMessageItemId());
+    }
+}
+
 void FollowUpReminderInfoWidget::slotCustomContextMenuRequested(const QPoint &pos)
 {
     Q_UNUSED(pos)
@@ -213,13 +245,12 @@ void FollowUpReminderInfoWidget::deleteItems(const QList<QTreeWidgetItem *> &mai
     if (mailItemLst.isEmpty()) {
         qCDebug(FOLLOWUPREMINDERAGENT_LOG) << "Not item selected";
     } else {
-        const int answer =
-            KMessageBox::warningYesNo(this,
-                                      i18np("Do you want to delete this selected item?", "Do you want to delete these %1 selected items?", mailItemLst.count()),
-                                      i18nc("@title:window", "Delete Items"),
-                                      KStandardGuiItem::del(),
-                                      KStandardGuiItem::cancel());
-        if (answer == KMessageBox::Yes) {
+        const auto answer = KMessageBox::warningContinueCancel(
+            this,
+            i18np("Do you want to delete this selected item?", "Do you want to delete these %1 selected items?", mailItemLst.count()),
+            i18nc("@title:window", "Delete Items"),
+            KStandardGuiItem::del());
+        if (answer == KMessageBox::Continue) {
             for (QTreeWidgetItem *item : mailItemLst) {
                 auto mailItem = static_cast<FollowUpReminderInfoItem *>(item);
                 mListRemoveId << mailItem->info()->uniqueIdentifier();
