@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,6 @@
 #include "sendlateragentadaptor.h"
 #include "sendlateragentsettings.h"
 #include "sendlaterconfiguredialog.h"
-#include "sendlaterinfo.h"
 #include "sendlatermanager.h"
 #include "sendlaterremovemessagejob.h"
 #include "sendlaterutil.h"
@@ -19,18 +18,19 @@
 #include <Akonadi/ChangeRecorder>
 #include <Akonadi/CollectionFetchScope>
 #include <Akonadi/ItemFetchScope>
-#include <Akonadi/KMime/SpecialMailCollections>
 #include <Akonadi/ServerManager>
 #include <Akonadi/Session>
+#include <Akonadi/SpecialMailCollections>
 #include <KMime/Message>
+#include <MessageComposer/SendLaterInfo>
 #include <QDBusConnection>
 
 #include <KWindowSystem>
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
 #endif
 #include <QPointer>
+#include <QTimer>
 #include <chrono>
 
 using namespace std::chrono_literals;
@@ -41,7 +41,7 @@ SendLaterAgent::SendLaterAgent(const QString &id)
     : Akonadi::AgentBase(id)
     , mManager(new SendLaterManager(this))
 {
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("sendlateragent"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_sendlater_agentrc") << QStringLiteral("akonadi_sendlater_agent.notifyrc"));
     migrate.migrate();
