@@ -8,8 +8,8 @@
 
 #include <config-ktnef.h> // WORDS_BIGENDIAN
 
-#include <assert.h>
-#include <math.h>
+#include <cassert>
+#include <cmath>
 
 #include <QBuffer>
 #include <QDataStream>
