@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,7 @@
 #include <MailCommon/MailKernel>
 
 #include <Akonadi/EntityDisplayAttribute>
-#include <Akonadi/KMime/MessageFolderAttribute>
+#include <Akonadi/MessageFolderAttribute>
 
 #include "kmail_debug.h"
 #include <KIconButton>
