@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -9,20 +9,20 @@
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include "configuredialog/colorlistbox.h"
 #include "kmkernel.h"
-#include "messagelistsettings.h"
 #include <Libkdepim/LineEditCatchReturnKey>
 #include <MailCommon/TagWidget>
 #include <MessageList/AggregationComboBox>
 #include <MessageList/AggregationConfigButton>
 #include <MessageList/ThemeComboBox>
 #include <MessageList/ThemeConfigButton>
+#include <messagelist/messagelistsettings.h>
 
 #include "util.h"
 #include <MailCommon/FolderTreeWidget>
 
 #include "kmmainwidget.h"
 
-#include "mailcommonsettings_base.h"
+#include <mailcommon/mailcommonsettings_base.h>
 
 #include <MessageViewer/ConfigureWidget>
 #include <MessageViewer/MessageViewerSettings>
@@ -34,16 +34,15 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 
 #include <MailCommon/MailUtil>
 
-#include <AkonadiCore/Tag>
-#include <AkonadiCore/TagAttribute>
-#include <AkonadiCore/TagCreateJob>
-#include <AkonadiCore/TagDeleteJob>
-#include <AkonadiCore/TagFetchJob>
-#include <AkonadiCore/TagFetchScope>
-#include <AkonadiCore/TagModifyJob>
+#include <Akonadi/Tag>
+#include <Akonadi/TagAttribute>
+#include <Akonadi/TagCreateJob>
+#include <Akonadi/TagDeleteJob>
+#include <Akonadi/TagFetchJob>
+#include <Akonadi/TagFetchScope>
+#include <Akonadi/TagModifyJob>
 
 #include "kmail_debug.h"
-#include <KColorScheme>
 #include <KFontChooser>
 #include <KIconButton>
 #include <KKeySequenceWidget>
@@ -55,17 +54,20 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <QLineEdit>
 
 #include <KMime/DateFormatter>
-using KMime::DateFormatter;
 
 #include <QButtonGroup>
 #include <QCheckBox>
 #include <QFontDatabase>
+#include <QFormLayout>
 #include <QGroupBox>
 #include <QLabel>
 #include <QRadioButton>
 #include <QSpinBox>
 #include <QVBoxLayout>
 #include <QWhatsThis>
+#include <KLazyLocalizedString>
+
+using KMime::DateFormatter;
 using namespace MailCommon;
 
 QString AppearancePage::helpAnchor() const
@@ -79,60 +81,60 @@ AppearancePage::AppearancePage(QWidget *parent, const QVariantList &args)
     //
     // "General" tab:
     //
-    auto readerTab = new ReaderTab();
+    auto readerTab = new AppearancePageGeneralTab();
     addTab(readerTab, i18n("General"));
     addConfig(MessageViewer::MessageViewerSettings::self(), readerTab);
 
     //
     // "Fonts" tab:
     //
-    auto fontsTab = new FontsTab();
+    auto fontsTab = new AppearancePageFontsTab();
     addTab(fontsTab, i18n("Fonts"));
 
     //
     // "Colors" tab:
     //
-    auto colorsTab = new ColorsTab();
+    auto colorsTab = new AppearancePageColorsTab();
     addTab(colorsTab, i18n("Colors"));
 
     //
     // "Layout" tab:
     //
-    auto layoutTab = new LayoutTab();
+    auto layoutTab = new AppearancePageLayoutTab();
     addTab(layoutTab, i18n("Layout"));
 
     //
     // "Headers" tab:
     //
-    auto headersTab = new HeadersTab();
+    auto headersTab = new AppearancePageHeadersTab();
     addTab(headersTab, i18n("Message List"));
 
     //
     // "Message Tag" tab:
     //
-    auto messageTagTab = new MessageTagTab();
+    auto messageTagTab = new AppearancePageMessageTagTab();
     addTab(messageTagTab, i18n("Message Tags"));
 }
 
-QString AppearancePage::FontsTab::helpAnchor() const
+QString AppearancePageFontsTab::helpAnchor() const
 {
     return QStringLiteral("configure-appearance-fonts");
 }
 
 static const struct {
     const char *configName;
-    const char *displayName;
+    const KLazyLocalizedString displayName;
     bool enableFamilyAndSize;
     bool onlyFixed;
 } fontNames[] = {
-    {"body-font", I18N_NOOP("Message Body"), true, false},
-    {"MessageListFont", I18N_NOOP("Message List"), true, false},
-    {"UnreadMessageFont", I18N_NOOP("Message List - Unread Messages"), false, false},
-    {"ImportantMessageFont", I18N_NOOP("Message List - Important Messages"), false, false},
-    {"TodoMessageFont", I18N_NOOP("Message List - Action Item Messages"), false, false},
-    {"fixed-font", I18N_NOOP("Fixed Width Font"), true, true},
-    {"composer-font", I18N_NOOP("Composer"), true, false},
-    {"print-font", I18N_NOOP("Printing Output"), true, false},
+    {"body-font", kli18n("Message Body"), true, false},
+    {"MessageListFont", kli18n("Message List"), true, false},
+    {"UnreadMessageFont", kli18n("Message List - Unread Messages"), false, false},
+    {"ImportantMessageFont", kli18n("Message List - Important Messages"), false, false},
+    {"TodoMessageFont", kli18n("Message List - Action Item Messages"), false, false},
+    {"fixed-font", kli18n("Fixed Width Font"), true, true},
+    {"composer-font", kli18n("Composer"), true, false},
+    {"print-font", kli18n("Printing Output"), true, false},
 };
 static const int numFontNames = sizeof fontNames / sizeof *fontNames;
 
@@ -157,7 +159,7 @@ AppearancePageFontsTab::AppearancePageFontsTab(QWidget *parent)
     QStringList fontDescriptions;
     fontDescriptions.reserve(numFontNames);
     for (int i = 0; i < numFontNames; ++i) {
-        fontDescriptions << i18n(fontNames[i].displayName);
+        fontDescriptions << fontNames[i].displayName.toString();
     }
     mFontLocationCombo->addItems(fontDescriptions);
 
@@ -168,7 +170,8 @@ AppearancePageFontsTab::AppearancePageFontsTab(QWidget *parent)
 
     hlay->addWidget(mFontLocationCombo);
     hlay->addStretch(10);
-    mFontChooser = new KFontChooser(this, KFontChooser::DisplayFrame, QStringList(), 4);
+    mFontChooser = new KFontChooser(KFontChooser::DisplayFrame, this);
+    mFontChooser->setMinVisibleItems(4);
     mFontChooser->setEnabled(false); // since !mCustomFontCheck->isChecked()
     vlay->addWidget(mFontChooser);
     connect(mFontChooser, &KFontChooser::fontSelected, this, &ConfigModuleTab::slotEmitChanged);
@@ -178,10 +181,10 @@ AppearancePageFontsTab::AppearancePageFontsTab(QWidget *parent)
     connect(mCustomFontCheck, &QAbstractButton::toggled, mFontLocationCombo, &QWidget::setEnabled);
     connect(mCustomFontCheck, &QAbstractButton::toggled, mFontChooser, &QWidget::setEnabled);
     // load the right font settings into mFontChooser:
-    connect(mFontLocationCombo, qOverload<int>(&QComboBox::activated), this, &AppearancePage::FontsTab::slotFontSelectorChanged);
+    connect(mFontLocationCombo, &QComboBox::activated, this, &AppearancePageFontsTab::slotFontSelectorChanged);
 }
 
-void AppearancePage::FontsTab::slotFontSelectorChanged(int index)
+void AppearancePageFontsTab::slotFontSelectorChanged(int index)
 {
     qCDebug(KMAIL_LOG) << "slotFontSelectorChanged() called";
     if (index < 0 || index >= mFontLocationCombo->count()) {
@@ -218,7 +221,7 @@ void AppearancePage::FontsTab::slotFontSelectorChanged(int index)
     mFontChooser->enableColumn(KFontChooser::FamilyList | KFontChooser::SizeList, fontNames[index].enableFamilyAndSize);
 }
 
-void AppearancePage::FontsTab::doLoadOther()
+void AppearancePageFontsTab::doLoadOther()
 {
     if (KMKernel::self()) {
         KConfigGroup fonts(KMKernel::self()->config(), "Fonts");
@@ -248,7 +251,7 @@ void AppearancePage::FontsTab::doLoadOther()
     }
 }
 
-void AppearancePage::FontsTab::save()
+void AppearancePageFontsTab::save()
 {
     if (KMKernel::self()) {
         KConfigGroup fonts(KMKernel::self()->config(), "Fonts");
@@ -282,31 +285,31 @@ void AppearancePage::FontsTab::save()
     }
 }
 
-void AppearancePage::FontsTab::doResetToDefaultsOther()
+void AppearancePageFontsTab::doResetToDefaultsOther()
 {
     mCustomFontCheck->setChecked(false);
 }
 
-QString AppearancePage::ColorsTab::helpAnchor() const
+QString AppearancePageColorsTab::helpAnchor() const
 {
     return QStringLiteral("configure-appearance-colors");
 }
 
 static const struct {
     const char *configName;
-    const char *displayName;
+    const KLazyLocalizedString displayName;
 } colorNames[] = { // adjust doLoadOther if you change this:
-    {"QuotedText1", I18N_NOOP("Quoted Text - First Level")},
-    {"QuotedText2", I18N_NOOP("Quoted Text - Second Level")},
-    {"QuotedText3", I18N_NOOP("Quoted Text - Third Level")},
-    {"LinkColor", I18N_NOOP("Link")},
-    {"UnreadMessageColor", I18N_NOOP("Unread Message")},
-    {"ImportantMessageColor", I18N_NOOP("Important Message")},
-    {"TodoMessageColor", I18N_NOOP("Action Item Message")},
-    {"ColorbarBackgroundPlain", I18N_NOOP("HTML Status Bar Background - No HTML Message")},
-    {"ColorbarForegroundPlain", I18N_NOOP("HTML Status Bar Foreground - No HTML Message")},
-    {"ColorbarBackgroundHTML", I18N_NOOP("HTML Status Bar Background - HTML Message")},
-    {"ColorbarForegroundHTML", I18N_NOOP("HTML Status Bar Foreground - HTML Message")}};
+    {"QuotedText1", kli18n("Quoted Text - First Level")},
+    {"QuotedText2", kli18n("Quoted Text - Second Level")},
+    {"QuotedText3", kli18n("Quoted Text - Third Level")},
+    {"LinkColor", kli18n("Link")},
+    {"UnreadMessageColor", kli18n("Unread Message")},
+    {"ImportantMessageColor", kli18n("Important Message")},
+    {"TodoMessageColor", kli18n("Action Item Message")},
+    {"ColorbarBackgroundPlain", kli18n("HTML Status Bar Background - No HTML Message")},
+    {"ColorbarForegroundPlain", kli18n("HTML Status Bar Foreground - No HTML Message")},
+    {"ColorbarBackgroundHTML", kli18n("HTML Status Bar Background - HTML Message")},
+    {"ColorbarForegroundHTML", kli18n("HTML Status Bar Foreground - HTML Message")}};
 static const int numColorNames = sizeof colorNames / sizeof *colorNames;
 
 AppearancePageColorsTab::AppearancePageColorsTab(QWidget *parent)
@@ -326,7 +329,7 @@ AppearancePageColorsTab::AppearancePageColorsTab(QWidget *parent)
     mColorList = new ColorListBox(this);
     mColorList->setEnabled(false); // since !mCustomColorCheck->isChecked()
     for (int i = 0; i < numColorNames; ++i) {
-        mColorList->addColor(i18n(colorNames[i].displayName));
+        mColorList->addColor(colorNames[i].displayName.toString());
     }
     vlay->addWidget(mColorList, 1);
 
@@ -344,7 +347,7 @@ AppearancePageColorsTab::AppearancePageColorsTab(QWidget *parent)
     mCloseToQuotaThreshold = new QSpinBox(this);
     mCloseToQuotaThreshold->setRange(0, 100);
     mCloseToQuotaThreshold->setSingleStep(1);
-    connect(mCloseToQuotaThreshold, qOverload<int>(&QSpinBox::valueChanged), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mCloseToQuotaThreshold, &QSpinBox::valueChanged, this, &ConfigModuleTab::slotEmitChanged);
     mCloseToQuotaThreshold->setSuffix(i18n("%"));
 
     hbox->addWidget(mCloseToQuotaThreshold);
@@ -357,7 +360,7 @@ AppearancePageColorsTab::AppearancePageColorsTab(QWidget *parent)
     connect(mColorList, &ColorListBox::changed, this, &ConfigModuleTab::slotEmitChanged);
 }
 
-void AppearancePage::ColorsTab::doLoadOther()
+void AppearancePageColorsTab::doLoadOther()
 {
     mCustomColorCheck->setChecked(!MessageCore::MessageCoreSettings::self()->useDefaultColors());
     mUseInlineStyle->setChecked(MessageCore::MessageCoreSettings::self()->useRealHtmlMailColor());
@@ -366,7 +369,7 @@ void AppearancePage::ColorsTab::doLoadOther()
     loadColor(true);
 }
 
-void AppearancePage::ColorsTab::loadColor(bool loadFromConfig)
+void AppearancePageColorsTab::loadColor(bool loadFromConfig)
 {
     if (KMKernel::self()) {
         KConfigGroup reader(KMKernel::self()->config(), "Reader");
@@ -406,7 +409,7 @@ void AppearancePage::ColorsTab::loadColor(bool loadFromConfig)
     }
 }
 
-void AppearancePage::ColorsTab::doResetToDefaultsOther()
+void AppearancePageColorsTab::doResetToDefaultsOther()
 {
     mCustomColorCheck->setChecked(false);
     mUseInlineStyle->setChecked(false);
@@ -415,7 +418,7 @@ void AppearancePage::ColorsTab::doResetToDefaultsOther()
     loadColor(false);
 }
 
-void AppearancePage::ColorsTab::save()
+void AppearancePageColorsTab::save()
 {
     if (!KMKernel::self()) {
         return;
@@ -443,7 +446,7 @@ void AppearancePage::ColorsTab::save()
     KMailSettings::self()->setCloseToQuotaThreshold(mCloseToQuotaThreshold->value());
 }
 
-QString AppearancePage::LayoutTab::helpAnchor() const
+QString AppearancePageLayoutTab::helpAnchor() const
 {
     return QStringLiteral("configure-appearance-layout");
 }
@@ -459,7 +462,7 @@ AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
                         Qt::Vertical,
                         KMailSettings::self()->folderListItem());
     vlay->addWidget(mFolderListGroupBox);
-    connect(mFolderListGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mFolderListGroup, &QButtonGroup::buttonClicked, this, &ConfigModuleTab::slotEmitChanged);
 
     auto folderCBHLayout = new QHBoxLayout;
     mFolderQuickSearchCB = new QCheckBox(i18n("Show folder quick search field"), this);
@@ -472,7 +475,7 @@ AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
     mFavoriteFoldersViewGroupBox->setTitle(i18n("Show Favorite Folders View"));
     mFavoriteFoldersViewGroupBox->setLayout(new QVBoxLayout());
     mFavoriteFoldersViewGroup = new QButtonGroup(this);
-    connect(mFavoriteFoldersViewGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mFavoriteFoldersViewGroup, &QButtonGroup::buttonClicked, this, &ConfigModuleTab::slotEmitChanged);
 
     auto favoriteFoldersViewHiddenRadio = new QRadioButton(i18n("Never"), mFavoriteFoldersViewGroupBox);
     mFavoriteFoldersViewGroup->addButton(favoriteFoldersViewHiddenRadio,
@@ -496,7 +499,7 @@ AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
     mFolderToolTipsGroupBox->setTitle(i18n("Folder Tooltips"));
     mFolderToolTipsGroupBox->setLayout(new QVBoxLayout());
     mFolderToolTipsGroup = new QButtonGroup(this);
-    connect(mFolderToolTipsGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mFolderToolTipsGroup, &QButtonGroup::buttonClicked, this, &ConfigModuleTab::slotEmitChanged);
 
     auto folderToolTipsAlwaysRadio = new QRadioButton(i18n("Always"), mFolderToolTipsGroupBox);
     mFolderToolTipsGroup->addButton(folderToolTipsAlwaysRadio, static_cast<int>(FolderTreeWidget::DisplayAlways));
@@ -515,12 +518,12 @@ AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
                         KMailSettings::self()->readerWindowModeItem());
     vlay->addWidget(mReaderWindowModeGroupBox);
 
-    connect(mReaderWindowModeGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mReaderWindowModeGroup, &QButtonGroup::buttonClicked, this, &ConfigModuleTab::slotEmitChanged);
 
     vlay->addStretch(10); // spacer
 }
 
-void AppearancePage::LayoutTab::doLoadOther()
+void AppearancePageLayoutTab::doLoadOther()
 {
     loadWidget(mFolderListGroupBox, mFolderListGroup, KMailSettings::self()->folderListItem());
     loadWidget(mReaderWindowModeGroupBox, mReaderWindowModeGroup, KMailSettings::self()->readerWindowModeItem());
@@ -534,7 +537,7 @@ void AppearancePage::LayoutTab::doLoadOther()
     }
 }
 
-void AppearancePage::LayoutTab::save()
+void AppearancePageLayoutTab::save()
 {
     saveButtonGroup(mFolderListGroup, KMailSettings::self()->folderListItem());
     saveButtonGroup(mReaderWindowModeGroup, KMailSettings::self()->readerWindowModeItem());
@@ -549,94 +552,80 @@ void AppearancePage::LayoutTab::save()
 // Appearance Message List
 //
 
-QString AppearancePage::HeadersTab::helpAnchor() const
+QString AppearancePageHeadersTab::helpAnchor() const
 {
     return QStringLiteral("configure-appearance-headers");
 }
 
 static const struct {
-    const char *displayName;
+    const KLazyLocalizedString displayName;
     DateFormatter::FormatType dateDisplay;
-} dateDisplayConfig[] = {{I18N_NOOP("Sta&ndard format (%1)"), KMime::DateFormatter::CTime},
-                         {I18N_NOOP("Locali&zed format (%1)"), KMime::DateFormatter::Localized},
-                         {I18N_NOOP("Smart for&mat (%1)"), KMime::DateFormatter::Fancy},
-                         {I18N_NOOP("C&ustom format:"), KMime::DateFormatter::Custom}};
+} dateDisplayConfig[] = {{kli18n("Sta&ndard format (%1)"), KMime::DateFormatter::CTime},
+                         {kli18n("Locali&zed format (%1)"), KMime::DateFormatter::Localized},
+                         {kli18n("Smart for&mat (%1)"), KMime::DateFormatter::Fancy},
+                         {kli18n("C&ustom format:"), KMime::DateFormatter::Custom}};
 static const int numDateDisplayConfig = sizeof dateDisplayConfig / sizeof *dateDisplayConfig;
 
 AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
-    auto vlay = new QVBoxLayout(this);
+    auto formLayout = new QFormLayout(this);
 
-    // "General Options" group:
-    auto group = new QGroupBox(i18nc("General options for the message list.", "General"), this);
-    auto gvlay = new QVBoxLayout(group);
-
-    mDisplayMessageToolTips = new QCheckBox(MessageList::MessageListSettings::self()->messageToolTipEnabledItem()->label(), group);
-    gvlay->addWidget(mDisplayMessageToolTips);
+    mDisplayMessageToolTips = new QCheckBox(MessageList::MessageListSettings::self()->messageToolTipEnabledItem()->label(), this);
+    formLayout->addRow(QString(), mDisplayMessageToolTips);
 
     connect(mDisplayMessageToolTips, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
 
     // "Aggregation"
     using MessageList::Utils::AggregationComboBox;
-    mAggregationComboBox = new AggregationComboBox(group);
-
-    auto aggregationLabel = new QLabel(i18n("Default aggregation:"), group);
-    aggregationLabel->setBuddy(mAggregationComboBox);
+    mAggregationComboBox = new AggregationComboBox(this);
 
     using MessageList::Utils::AggregationConfigButton;
-    auto aggregationConfigButton = new AggregationConfigButton(group, mAggregationComboBox);
+    auto aggregationConfigButton = new AggregationConfigButton(this, mAggregationComboBox);
 
     auto aggregationLayout = new QHBoxLayout();
-    aggregationLayout->addWidget(aggregationLabel, 1);
     aggregationLayout->addWidget(mAggregationComboBox, 1);
     aggregationLayout->addWidget(aggregationConfigButton, 0);
-    gvlay->addLayout(aggregationLayout);
+    formLayout->addRow(i18n("Default aggregation:"), aggregationLayout);
 
     connect(aggregationConfigButton,
             &MessageList::Utils::AggregationConfigButton::configureDialogCompleted,
             this,
             &AppearancePageHeadersTab::slotSelectDefaultAggregation);
-    connect(mAggregationComboBox, qOverload<int>(&MessageList::Utils::AggregationComboBox::activated), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mAggregationComboBox, &MessageList::Utils::AggregationComboBox::activated, this, &ConfigModuleTab::slotEmitChanged);
 
     // "Theme"
     using MessageList::Utils::ThemeComboBox;
-    mThemeComboBox = new ThemeComboBox(group);
-
-    auto themeLabel = new QLabel(i18n("Default theme:"), group);
-    themeLabel->setBuddy(mThemeComboBox);
+    mThemeComboBox = new ThemeComboBox(this);
 
     using MessageList::Utils::ThemeConfigButton;
-    auto themeConfigButton = new ThemeConfigButton(group, mThemeComboBox);
+    auto themeConfigButton = new ThemeConfigButton(this, mThemeComboBox);
 
     auto themeLayout = new QHBoxLayout();
-    themeLayout->addWidget(themeLabel, 1);
     themeLayout->addWidget(mThemeComboBox, 1);
     themeLayout->addWidget(themeConfigButton, 0);
-    gvlay->addLayout(themeLayout);
+    formLayout->addRow(i18n("Default theme:"), themeLayout);
 
     connect(themeConfigButton, &MessageList::Utils::ThemeConfigButton::configureDialogCompleted, this, &AppearancePageHeadersTab::slotSelectDefaultTheme);
-    connect(mThemeComboBox, qOverload<int>(&MessageList::Utils::ThemeComboBox::activated), this, &ConfigModuleTab::slotEmitChanged);
-
-    vlay->addWidget(group);
+    connect(mThemeComboBox, &MessageList::Utils::ThemeComboBox::activated, this, &ConfigModuleTab::slotEmitChanged);
 
     // "Date Display" group:
-    mDateDisplayBox = new QGroupBox(this);
-    mDateDisplayBox->setTitle(i18n("Date Display"));
     mDateDisplay = new QButtonGroup(this);
     mDateDisplay->setExclusive(true);
-    gvlay = new QVBoxLayout(mDateDisplayBox);
 
     for (int i = 0; i < numDateDisplayConfig; ++i) {
-        const char *label = dateDisplayConfig[i].displayName;
+        const char *label = KLocalizedString(dateDisplayConfig[i].displayName).untranslatedText().constData();
+
         QString buttonLabel;
         if (QString::fromLatin1(label).contains(QLatin1String("%1"))) {
-            buttonLabel = i18n(label, DateFormatter::formatCurrentDate(dateDisplayConfig[i].dateDisplay));
+            buttonLabel = KLocalizedString(dateDisplayConfig[i].displayName)
+                              .subs(DateFormatter::formatCurrentDate(dateDisplayConfig[i].dateDisplay))
+                              .toString(); // i18n(label, DateFormatter::formatCurrentDate(dateDisplayConfig[i].dateDisplay));
         } else {
             buttonLabel = i18n(label);
         }
         if (dateDisplayConfig[i].dateDisplay == DateFormatter::Custom) {
-            auto hbox = new QWidget(mDateDisplayBox);
+            auto hbox = new QWidget(this);
             auto hboxHBoxLayout = new QHBoxLayout(hbox);
             hboxHBoxLayout->setContentsMargins({});
             auto radio = new QRadioButton(buttonLabel, hbox);
@@ -691,18 +680,19 @@ AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
                 "</strong></p></qt>");
             mCustomDateFormatEdit->setWhatsThis(mCustomDateWhatsThis);
             radio->setWhatsThis(mCustomDateWhatsThis);
-            gvlay->addWidget(hbox);
+            formLayout->addRow(QString(), hbox);
         } else {
             auto radio = new QRadioButton(buttonLabel, mDateDisplayBox);
-            gvlay->addWidget(radio);
+            if (i == 0) {
+                formLayout->addRow(i18n("Date Display:"), radio);
+            } else {
+                formLayout->addRow(QString(), radio);
+            }
             mDateDisplay->addButton(radio, dateDisplayConfig[i].dateDisplay);
         }
     } // end for loop populating mDateDisplay
 
-    vlay->addWidget(mDateDisplayBox);
-    connect(mDateDisplay, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
-
-    vlay->addStretch(10); // spacer
+    connect(mDateDisplay, &QButtonGroup::buttonClicked, this, &ConfigModuleTab::slotEmitChanged);
 }
 
 void AppearancePageHeadersTab::slotLinkClicked(const QString &link)
@@ -712,19 +702,19 @@ void AppearancePageHeadersTab::slotLinkClicked(const QString &link)
     }
 }
 
-void AppearancePage::HeadersTab::slotSelectDefaultAggregation()
+void AppearancePageHeadersTab::slotSelectDefaultAggregation()
 {
     // Select current default aggregation.
     mAggregationComboBox->selectDefault();
 }
 
-void AppearancePage::HeadersTab::slotSelectDefaultTheme()
+void AppearancePageHeadersTab::slotSelectDefaultTheme()
 {
     // Select current default theme.
     mThemeComboBox->selectDefault();
 }
 
-void AppearancePage::HeadersTab::doLoadOther()
+void AppearancePageHeadersTab::doLoadOther()
 {
     // "General Options":
     loadWidget(mDisplayMessageToolTips, MessageList::MessageListSettings::self()->messageToolTipEnabledItem());
@@ -739,7 +729,7 @@ void AppearancePage::HeadersTab::doLoadOther()
     setDateDisplay(MessageCore::MessageCoreSettings::self()->dateFormat(), MessageCore::MessageCoreSettings::self()->customDateFormat());
 }
 
-void AppearancePage::HeadersTab::doLoadFromGlobalSettings()
+void AppearancePageHeadersTab::doLoadFromGlobalSettings()
 {
     loadWidget(mDisplayMessageToolTips, MessageList::MessageListSettings::self()->messageToolTipEnabledItem());
     // "Aggregation":
@@ -751,7 +741,7 @@ void AppearancePage::HeadersTab::doLoadFromGlobalSettings()
     setDateDisplay(MessageCore::MessageCoreSettings::self()->dateFormat(), MessageCore::MessageCoreSettings::self()->customDateFormat());
 }
 
-void AppearancePage::HeadersTab::setDateDisplay(int num, const QString &format)
+void AppearancePageHeadersTab::setDateDisplay(int num, const QString &format)
 {
     auto dateDisplay = static_cast<DateFormatter::FormatType>(num);
 
@@ -770,7 +760,7 @@ void AppearancePage::HeadersTab::setDateDisplay(int num, const QString &format)
     mDateDisplay->button(numDateDisplayConfig - 2)->setChecked(true); // default
 }
 
-void AppearancePage::HeadersTab::save()
+void AppearancePageHeadersTab::save()
 {
     saveCheckBox(mDisplayMessageToolTips, MessageList::MessageListSettings::self()->messageToolTipEnabledItem());
 
@@ -792,7 +782,7 @@ void AppearancePage::HeadersTab::save()
 // Message Window
 //
 
-QString AppearancePage::ReaderTab::helpAnchor() const
+QString AppearancePageGeneralTab::helpAnchor() const
 {
     return QStringLiteral("configure-appearance-reader");
 }
@@ -852,11 +842,11 @@ AppearancePageGeneralTab::AppearancePageGeneralTab(QWidget *parent)
     topLayout->addStretch(100); // spacer
 }
 
-void AppearancePage::ReaderTab::doResetToDefaultsOther()
+void AppearancePageGeneralTab::doResetToDefaultsOther()
 {
 }
 
-void AppearancePage::ReaderTab::doLoadOther()
+void AppearancePageGeneralTab::doLoadOther()
 {
     loadWidget(mSystemTrayCheck, KMailSettings::self()->systemTrayEnabledItem());
     loadWidget(mStartInTrayCheck, KMailSettings::self()->startInTrayItem());
@@ -865,7 +855,7 @@ void AppearancePage::ReaderTab::doLoadOther()
     mViewerSettings->readConfig();
 }
 
-void AppearancePage::ReaderTab::save()
+void AppearancePageGeneralTab::save()
 {
     saveCheckBox(mSystemTrayCheck, KMailSettings::self()->systemTrayEnabledItem());
     saveCheckBox(mStartInTrayCheck, KMailSettings::self()->startInTrayItem());
@@ -875,7 +865,7 @@ void AppearancePage::ReaderTab::save()
     mViewerSettings->writeConfig();
 }
 
-QString AppearancePage::MessageTagTab::helpAnchor() const
+QString AppearancePageMessageTagTab::helpAnchor() const
 {
     return QStringLiteral("configure-appearance-messagetag");
 }
@@ -982,7 +972,7 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
     connect(mTagWidget, &TagWidget::changed, this, &AppearancePageMessageTagTab::slotEmitChangeCheck);
 
     // For enabling the add button in case box is non-empty
-    connect(mTagAddLineEdit, &QLineEdit::textChanged, this, &AppearancePage::MessageTagTab::slotAddLineTextChanged);
+    connect(mTagAddLineEdit, &QLineEdit::textChanged, this, &AppearancePageMessageTagTab::slotAddLineTextChanged);
 
     // For on-the-fly updating of tag name in editbox
     connect(mTagWidget->tagNameLineEdit(), &QLineEdit::textChanged, this, &AppearancePageMessageTagTab::slotNameLineTextChanged);
@@ -1008,12 +998,12 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
 
 AppearancePageMessageTagTab::~AppearancePageMessageTagTab() = default;
 
-void AppearancePage::MessageTagTab::slotEmitChangeCheck()
+void AppearancePageMessageTagTab::slotEmitChangeCheck()
 {
     slotEmitChanged();
 }
 
-void AppearancePage::MessageTagTab::slotRowsMoved(const QModelIndex &, int sourcestart, int sourceEnd, const QModelIndex &, int destinationRow)
+void AppearancePageMessageTagTab::slotRowsMoved(const QModelIndex &, int sourcestart, int sourceEnd, const QModelIndex &, int destinationRow)
 {
     Q_UNUSED(sourceEnd)
     Q_UNUSED(sourcestart)
@@ -1022,7 +1012,7 @@ void AppearancePage::MessageTagTab::slotRowsMoved(const QModelIndex &, int sourc
     slotEmitChangeCheck();
 }
 
-void AppearancePage::MessageTagTab::updateButtons()
+void AppearancePageMessageTagTab::updateButtons()
 {
     const int currentIndex = mTagListBox->currentRow();
 
@@ -1034,7 +1024,7 @@ void AppearancePage::MessageTagTab::updateButtons()
     mTagDownButton->setEnabled(aFilterIsSelected && !theLast);
 }
 
-void AppearancePage::MessageTagTab::slotMoveTagUp()
+void AppearancePageMessageTagTab::slotMoveTagUp()
 {
     const int tmp_index = mTagListBox->currentRow();
     if (tmp_index <= 0) {
@@ -1044,7 +1034,7 @@ void AppearancePage::MessageTagTab::slotMoveTagUp()
     updateButtons();
 }
 
-void AppearancePage::MessageTagTab::slotMoveTagDown()
+void AppearancePageMessageTagTab::slotMoveTagDown()
 {
     const int tmp_index = mTagListBox->currentRow();
     if ((tmp_index < 0) || (tmp_index >= int(mTagListBox->count()) - 1)) {
@@ -1054,7 +1044,7 @@ void AppearancePage::MessageTagTab::slotMoveTagDown()
     updateButtons();
 }
 
-void AppearancePage::MessageTagTab::swapTagsInListBox(const int first, const int second)
+void AppearancePageMessageTagTab::swapTagsInListBox(const int first, const int second)
 {
     disconnect(mTagListBox, &QListWidget::currentItemChanged, this, &AppearancePageMessageTagTab::slotSelectionChanged);
     QListWidgetItem *item = mTagListBox->takeItem(first);
@@ -1067,7 +1057,7 @@ void AppearancePage::MessageTagTab::swapTagsInListBox(const int first, const int
     slotEmitChangeCheck();
 }
 
-void AppearancePage::MessageTagTab::slotRecordTagSettings(int aIndex)
+void AppearancePageMessageTagTab::slotRecordTagSettings(int aIndex)
 {
     if ((aIndex < 0) || (aIndex >= int(mTagListBox->count()))) {
         return;
@@ -1081,7 +1071,7 @@ void AppearancePage::MessageTagTab::slotRecordTagSettings(int aIndex)
     mTagWidget->recordTagSettings(tmp_desc);
 }
 
-void AppearancePage::MessageTagTab::slotUpdateTagSettingWidgets(int aIndex)
+void AppearancePageMessageTagTab::slotUpdateTagSettingWidgets(int aIndex)
 {
     // Check if selection is valid
     if ((aIndex < 0) || (mTagListBox->currentRow() < 0)) {
@@ -1101,11 +1091,11 @@ void AppearancePage::MessageTagTab::slotUpdateTagSettingWidgets(int aIndex)
     auto tagItem = static_cast<TagListWidgetItem *>(item);
     MailCommon::Tag::Ptr tmp_desc = tagItem->kmailTag();
 
-    disconnect(mTagWidget->tagNameLineEdit(), &QLineEdit::textChanged, this, &AppearancePage::MessageTagTab::slotNameLineTextChanged);
+    disconnect(mTagWidget->tagNameLineEdit(), &QLineEdit::textChanged, this, &AppearancePageMessageTagTab::slotNameLineTextChanged);
 
     mTagWidget->tagNameLineEdit()->setEnabled(!tmp_desc->isImmutable);
     mTagWidget->tagNameLineEdit()->setText(tmp_desc->tagName);
-    connect(mTagWidget->tagNameLineEdit(), &QLineEdit::textChanged, this, &AppearancePage::MessageTagTab::slotNameLineTextChanged);
+    connect(mTagWidget->tagNameLineEdit(), &QLineEdit::textChanged, this, &AppearancePageMessageTagTab::slotNameLineTextChanged);
 
     mTagWidget->setTagTextColor(tmp_desc->textColor);
 
@@ -1123,7 +1113,7 @@ void AppearancePage::MessageTagTab::slotUpdateTagSettingWidgets(int aIndex)
     mTagWidget->inToolBarCheck()->setChecked(tmp_desc->inToolbar);
 }
 
-void AppearancePage::MessageTagTab::slotSelectionChanged()
+void AppearancePageMessageTagTab::slotSelectionChanged()
 {
     mEmitChanges = false;
     slotRecordTagSettings(mPreviousTag);
@@ -1132,12 +1122,16 @@ void AppearancePage::MessageTagTab::slotSelectionChanged()
     mEmitChanges = true;
 }
 
-void AppearancePage::MessageTagTab::slotRemoveTag()
+void AppearancePageMessageTagTab::slotRemoveTag()
 {
     const int tmp_index = mTagListBox->currentRow();
     if (tmp_index >= 0) {
         if (KMessageBox::Yes
-            == KMessageBox::questionYesNo(this, i18n("Do you want to remove tag \'%1\'?", mTagListBox->item(mTagListBox->currentRow())->text()))) {
+            == KMessageBox::questionYesNo(this,
+                                          i18n("Do you want to remove tag \'%1\'?", mTagListBox->item(mTagListBox->currentRow())->text()),
+                                          i18nc("@title:window", "Remove Tag"),
+                                          KStandardGuiItem::remove(),
+                                          KStandardGuiItem::cancel())) {
             QListWidgetItem *item = mTagListBox->takeItem(mTagListBox->currentRow());
             auto tagItem = static_cast<TagListWidgetItem *>(item);
             MailCommon::Tag::Ptr tmp_desc = tagItem->kmailTag();
@@ -1162,14 +1156,14 @@ void AppearancePage::MessageTagTab::slotRemoveTag()
     }
 }
 
-void AppearancePage::MessageTagTab::slotDeleteTagJob(KJob *job)
+void AppearancePageMessageTagTab::slotDeleteTagJob(KJob *job)
 {
     if (job->error()) {
         qCWarning(KMAIL_LOG) << "Failed to delete tag " << job->errorString();
     }
 }
 
-void AppearancePage::MessageTagTab::slotNameLineTextChanged(const QString &aText)
+void AppearancePageMessageTagTab::slotNameLineTextChanged(const QString &aText)
 {
     // If deleted all, leave the first character for the sake of not having an
     // empty tag name
@@ -1196,17 +1190,17 @@ void AppearancePage::MessageTagTab::slotNameLineTextChanged(const QString &aText
     connect(mTagListBox, &QListWidget::currentItemChanged, this, &AppearancePageMessageTagTab::slotSelectionChanged);
 }
 
-void AppearancePage::MessageTagTab::slotIconNameChanged(const QString &iconName)
+void AppearancePageMessageTagTab::slotIconNameChanged(const QString &iconName)
 {
     mTagListBox->currentItem()->setIcon(QIcon::fromTheme(iconName));
 }
 
-void AppearancePage::MessageTagTab::slotAddLineTextChanged(const QString &aText)
+void AppearancePageMessageTagTab::slotAddLineTextChanged(const QString &aText)
 {
     mTagAddButton->setEnabled(!aText.trimmed().isEmpty());
 }
 
-void AppearancePage::MessageTagTab::slotAddNewTag()
+void AppearancePageMessageTagTab::slotAddNewTag()
 {
     const QString newTagName = mTagAddLineEdit->text().trimmed();
     if (newTagName.isEmpty()) {
@@ -1233,7 +1227,7 @@ void AppearancePage::MessageTagTab::slotAddNewTag()
     mTagAddLineEdit->clear();
 }
 
-void AppearancePage::MessageTagTab::doLoadFromGlobalSettings()
+void AppearancePageMessageTagTab::doLoadFromGlobalSettings()
 {
     mTagListBox->clear();
 
@@ -1242,7 +1236,7 @@ void AppearancePage::MessageTagTab::doLoadFromGlobalSettings()
     connect(fetchJob, &KJob::result, this, &AppearancePageMessageTagTab::slotTagsFetched);
 }
 
-void AppearancePage::MessageTagTab::slotTagsFetched(KJob *job)
+void AppearancePageMessageTagTab::slotTagsFetched(KJob *job)
 {
     if (job->error()) {
         qCWarning(KMAIL_LOG) << "Failed to load tags " << job->errorString();
@@ -1284,7 +1278,7 @@ void AppearancePage::MessageTagTab::slotTagsFetched(KJob *job)
     }
 }
 
-void AppearancePage::MessageTagTab::save()
+void AppearancePageMessageTagTab::save()
 {
     const int currentRow = mTagListBox->currentRow();
     if (currentRow < 0) {
