@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -10,10 +10,8 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include "kmkernel.h"
 
 #include "configuredialog/configuredialoglistview.h"
-#include "globalsettings_templateparser.h"
 #include "kmmainwidget.h"
 #include "settings/kmailsettings.h"
-#include "templatesconfiguration_kfg.h"
 #include <MessageComposer/ImageScalingWidget>
 #include <MessageComposer/MessageComposerSettings>
 #include <MessageCore/MessageCoreSettings>
@@ -21,6 +19,8 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <PimCommon/SimpleStringListEditor>
 #include <TemplateParser/CustomTemplates>
 #include <TemplateParser/TemplatesConfiguration>
+#include <templateparser/globalsettings_templateparser.h>
+#include <templateparser/templatesconfiguration_kfg.h>
 
 #include <KLDAP/LdapClientSearch>
 #include <PimCommonAkonadi/CompletionOrderEditor>
@@ -43,6 +43,7 @@ using PimCommon::RecentAddresses;
 #include <QLabel>
 #include <QRegularExpression>
 #include <QRegularExpressionValidator>
+#include <QScrollArea>
 #include <QTextCodec>
 #include <QVBoxLayout>
 
@@ -124,7 +125,9 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
     // Main layout
-    auto grid = new QGridLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
+    auto wrapper = new QWidget;
+    auto layout = new QVBoxLayout(wrapper);
 
     // "Signature" group
     auto groupBox = new QGroupBox(i18nc("@title:group", "Signature"));
@@ -180,12 +183,11 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     groupVBoxLayout->addStretch(1);
 
     groupBox->setLayout(groupVBoxLayout);
-    grid->addWidget(groupBox, 0, 0);
+    layout->addWidget(groupBox);
 
     // "Format" group
     groupBox = new QGroupBox(i18nc("@title:group", "Format"));
-    auto groupGridLayout = new QGridLayout();
-    int row = 0;
+    groupVBoxLayout = new QVBoxLayout;
 
     // "Only quote selected text when replying" checkbox
     mQuoteSelectionOnlyCheck = new QCheckBox(MessageComposer::MessageComposerSettings::self()->quoteSelectionOnlyItem()->label(), this);
@@ -197,8 +199,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     mQuoteSelectionOnlyCheck->setWhatsThis(helpText);
 
     connect(mQuoteSelectionOnlyCheck, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
-    groupGridLayout->addWidget(mQuoteSelectionOnlyCheck, row, 0, 1, -1);
-    ++row;
+    groupVBoxLayout->addWidget(mQuoteSelectionOnlyCheck);
 
     // "Use smart quoting" checkbox
     mSmartQuoteCheck = new QCheckBox(TemplateParser::TemplateParserSettings::self()->smartQuoteItem()->label(), this);
@@ -210,8 +211,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     mSmartQuoteCheck->setWhatsThis(helpText);
 
     connect(mSmartQuoteCheck, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
-    groupGridLayout->addWidget(mSmartQuoteCheck, row, 0, 1, -1);
-    ++row;
+    groupVBoxLayout->addWidget(mSmartQuoteCheck);
 
     // "Word wrap at column" checkbox/spinbox
     mWordWrapCheck = new QCheckBox(MessageComposer::MessageComposerSettings::self()->wordWrapItem()->label(), this);
@@ -236,12 +236,13 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     // only enable the spinbox if the checkbox is checked
     connect(mWordWrapCheck, &QAbstractButton::toggled, mWrapColumnSpin, &QWidget::setEnabled);
 
-    groupGridLayout->addWidget(mWordWrapCheck, row, 0);
-    groupGridLayout->addWidget(mWrapColumnSpin, row, 1);
-    ++row;
-
-    // Spacing
-    ++row;
+    auto wordWrapWrapper = new QWidget;
+    auto wordWrapWrapperLayout = new QHBoxLayout(wordWrapWrapper);
+    wordWrapWrapperLayout->setContentsMargins(0, 0, 0, 0);
+    wordWrapWrapperLayout->addWidget(mWordWrapCheck);
+    wordWrapWrapperLayout->addWidget(mWrapColumnSpin);
+    wordWrapWrapperLayout->addStretch();
+    groupVBoxLayout->addWidget(wordWrapWrapper);
 
     // "Reply/Forward using HTML if present" checkbox
     mReplyUsingVisualFormat = new QCheckBox(TemplateParser::TemplateParserSettings::self()->replyUsingVisualFormatItem()->label(), this);
@@ -253,8 +254,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     mReplyUsingVisualFormat->setWhatsThis(helpText);
 
     connect(mReplyUsingVisualFormat, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
-    groupGridLayout->addWidget(mReplyUsingVisualFormat, row, 0, 1, -1);
-    ++row;
+    groupVBoxLayout->addWidget(mReplyUsingVisualFormat);
 
     // "Improve plain text of HTML" checkbox
     mImprovePlainTextOfHtmlMessage = new QCheckBox(MessageComposer::MessageComposerSettings::self()->improvePlainTextOfHtmlMessageItem()->label(), this);
@@ -268,11 +268,9 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     mImprovePlainTextOfHtmlMessage->setWhatsThis(helpText);
 
     connect(mImprovePlainTextOfHtmlMessage, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
-    groupGridLayout->addWidget(mImprovePlainTextOfHtmlMessage, row, 0, 1, -1);
-    ++row;
+    groupVBoxLayout->addWidget(mImprovePlainTextOfHtmlMessage);
     QLabel *label = nullptr;
 #if KDEPIM_ENTERPRISE_BUILD
-    ++row;
     // "Default forwarding type" combobox
     mForwardTypeCombo = new QComboBox(this);
     mForwardTypeCombo->addItems(QStringList() << i18nc("@item:inlistbox Inline mail forwarding", "Inline") << i18n("As Attachment"));
@@ -286,18 +284,27 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
 
     connect(mForwardTypeCombo, &QComboBox::activated, this, &ComposerPageGeneralTab::slotEmitChanged);
 
-    groupGridLayout->addWidget(label, row, 0);
-    groupGridLayout->addWidget(mForwardTypeCombo, row, 1);
+    auto forwardTypeWrapper = new QWidget;
+    auto forwardTypeWrapperLayout = new QHBoxLayout(forwardTypeWrapper);
+    forwardTypeWrapperLayout->setContentsMargins(0, 0, 0, 0);
+    forwardTypeWrapperLayout->addWidget(label);
+    forwardTypeWrapperLayout->addWidget(mForwardTypeCombo);
+    forwardTypeWrapperLayout->addStretch();
+    groupVBoxLayout->addWidget(forwardTypeWrapper);
 #endif
-    groupGridLayout->setRowStretch(row, 1);
 
-    groupBox->setLayout(groupGridLayout);
-    grid->addWidget(groupBox, 1, 0);
+    groupBox->setLayout(groupVBoxLayout);
+    layout->addWidget(groupBox);
 
     // "Recipients" group
     groupBox = new QGroupBox(i18nc("@title:group", "Recipients"));
-    groupGridLayout = new QGridLayout();
-    row = 0;
+    auto groupHBoxLayout = new QHBoxLayout(groupBox);
+    auto groupBoxWrapper = new QWidget;
+    auto groupGridLayout = new QGridLayout(groupBoxWrapper);
+    groupHBoxLayout->addWidget(groupBoxWrapper);
+    groupHBoxLayout->addStretch();
+
+    int row = 0;
 
     // "Automatically request MDNs" checkbox
     mAutoRequestMDNCheck = new QCheckBox(KMailSettings::self()->requestMDNItem()->label(), this);
@@ -425,11 +432,11 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     groupGridLayout->setRowStretch(row, 1);
 
     groupBox->setLayout(groupGridLayout);
-    grid->addWidget(groupBox, 0, 1);
+    layout->addWidget(groupBox);
 
+    // "Autosave" group
     groupBox = new QGroupBox(i18nc("@title:group", "Autosave"));
-    groupGridLayout = new QGridLayout();
-    row = 0;
+    groupHBoxLayout = new QHBoxLayout(groupBox);
 
     // "Autosave interval" spinbox
     mAutoSave = new KPluralHandlingSpinBox(this);
@@ -450,15 +457,17 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
 
     connect(mAutoSave, &QSpinBox::valueChanged, this, &ConfigModuleTab::slotEmitChanged);
 
-    groupGridLayout->addWidget(label, row, 0);
-    groupGridLayout->addWidget(mAutoSave, row, 1);
-    row++;
-    groupGridLayout->setRowStretch(row, 1);
-    groupBox->setLayout(groupGridLayout);
+    groupHBoxLayout->addWidget(label);
+    groupHBoxLayout->addWidget(mAutoSave);
+    groupHBoxLayout->addStretch();
 
-    grid->addWidget(groupBox, 1, 1);
+    layout->addWidget(groupBox);
 
-    grid->setRowStretch(2, 1);
+    // Prevent all other tabs to inherit the height of this one
+    auto scrollArea = new QScrollArea;
+    scrollArea->setWidgetResizable(true);
+    scrollArea->setWidget(wrapper);
+    mainLayout->addWidget(scrollArea);
 }
 
 void ComposerPageGeneralTab::doResetToDefaultsOther()
