@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "opencomposerhiddenjob.h"
-#include "composer.h"
 #include "editor/kmcomposerwin.h"
 #include "kmkernel.h"
+#include <MessageComposer/Composer>
 
 #include <MessageComposer/MessageHelper>
 
